puts "Running data capture script..."

puts "Connecting to the processor..."
	connect mb mdm

puts "Downloading the Microblaze program..."
	rst
	stop
	rst
	dow ADIEvalBoard.elf
	run
	stop

puts "Starting the data acquisition..."
	set startAcqAddr [mrd_var pStartAcquisition]
	set startAcqAddr [format "0x%08x" $startAcqAddr]
	set b [mrd $startAcqAddr]
    puts $b
    mwr $startAcqAddr 1
    set b [mrd $startAcqAddr]
    puts $b
	con
	after 2000
	stop

puts "Reading data from the system..."	
	set rxDataAddr [mrd_var pRxData]
	set rxDataAddr [format "0x%08x" $rxDataAddr]
	
	set conversionData {}
	set adcData [mrd $rxDataAddr 16384] 
	for { set i 1 } { $i < 32768 } { incr i 2} {		
		set val [string trimleft [lindex $adcData $i] 0]
		if { ![string length $val] } {
			set val "0"
		}
		set val [expr 0x$val]
		lappend conversionData $val
		lappend conversionData "\n"
		set addr [expr $rxDataAddr + 4]
		set rxDataAddr [format "0x%08x" $addr]
    }

# Create 8 lists, one for each channel
puts "Preparing data for output..."
    set final0 "Vin1"
    set final1 "Vin2"
    set final2 "Vin3"
    set final3 "Vin4"
    set final4 "Vin5"
    set final5 "Vin6"
    
    set coding 0
    
# Remove channel information from the read data
puts "Processing data..."
for {set i 0} {$i < [llength $conversionData]} {incr i 2} {
        set a [lindex $conversionData $i]
        set decimal [expr $a]
        
     switch [ expr $decimal / 65536 ] {
        0   {            
            if { $coding == 0 } {
                if { $decimal > 2048 } {
                    set decimal [expr $decimal - 4096]
                }
            }
            lappend final0 $decimal
        }        
        1   {
            set decimal [expr $decimal - 65536]
            if { $coding == 0 } {
                if { $decimal > 2048 } {
                    set decimal [expr $decimal - 4096]
                }
            }
            lappend final1 $decimal
        }
        2   {
            set decimal [expr $decimal - 131072 ]
            if { $coding == 0 } {
                if { $decimal > 2048 } {
                    set decimal [expr $decimal - 4096]
                }
            }
            lappend final2 $decimal
        }
        3   {
            set decimal [expr $decimal - 196608 ]
            if { $coding == 0 } {
                if { $decimal > 2048 } {
                    set decimal [expr $decimal - 4096]
                }
            }
            lappend final3 $decimal
        }
        4   {
            set decimal [expr $decimal - 262144 ]
            if { $coding == 0 } {
                if { $decimal > 2048 } {
                    set decimal [expr $decimal - 4096]
                }
            }
            lappend final4 $decimal
        }
        5   {
            set decimal [expr $decimal - 327680 ]
            if { $coding == 0 } {
                if { $decimal > 2048 } {
                    set decimal [expr $decimal - 4096]
                }
            }
            lappend final5 $decimal
        }     
        default {
            puts $decimal
            puts "ERR"
        }
    }
}

# Arrange data by channel    
set data_processed 1
puts "Arranging data according to channel..."
for {set i 0} {$i < 32769} {incr i} {

    if { [ llength $final0 ] > [ expr {$i ? $i : 1} ] } {
        lappend final [ lindex $final0 $i ],
        set data_processed 1
    }
    
    if { [ llength $final1 ] >  [ expr {$i ? $i : 1} ] } {
        lappend final [ lindex $final1 $i ],
        set data_processed 1
    }

    if { [ llength $final2 ] > [ expr {$i ? $i : 1} ] } {
        lappend final [ lindex $final2 $i ],
        set data_processed 1
    }

    if { [llength $final3] > [ expr {$i ? $i : 1} ] } {
        lappend final [lindex $final3 $i],
        set data_processed 1
    }

    if { [llength $final4] > [ expr {$i ? $i : 1} ] } {
        lappend final [lindex $final4 $i],
        set data_processed 1
    }

    if { [llength $final5] > [ expr {$i ? $i : 1} ] } {
        lappend final [lindex $final5 $i],
        set data_processed 1
    }
    
    if { $data_processed == 0 } {
        break
    }
    lappend final \n 
    set data_processed 0
} 
    
puts "Ending the Microblaze program..."	
	mwr $startAcqAddr 0	
	con

puts "Moving data into file Acquisition.csv..."
    set fd [ open "Acquisition.csv" "a+" ]
    puts -nonewline $fd [ join $final ]
    close $fd

puts "Disconnecting from the processor..."
	#stop
	#disconnect 0 
	
puts "Data acquisition is complete. Data is stored in the file Acquisition.csv."

