/**************************************************************************//**
*   @file   dma.h
*   @brief  Header file for DMA transfer functions.
*   @author ACozma (andrei.cozma@analog.com)
*
*******************************************************************************
* Copyright 2011(c) Analog Devices, Inc.
*
* All rights reserved.
*
* Redistribution and use in source and binary forms, with or without modification,
* are permitted provided that the following conditions are met:
*  - Redistributions of source code must retain the above copyright
*    notice, this list of conditions and the following disclaimer.
*  - Redistributions in binary form must reproduce the above copyright
*    notice, this list of conditions and the following disclaimer in
*    the documentation and/or other materials provided with the
*    distribution.
*  - Neither the name of Analog Devices, Inc. nor the names of its
*    contributors may be used to endorse or promote products derived
*    from this software without specific prior written permission.
*  - The use of this software may or may not infringe the patent rights
*    of one or more patent holders.  This license does not release you
*    from the requirement that you obtain separate licenses from these
*    patent holders to use this software.
*  - Use of the software either in source or binary form, must be run
*    on or directly connected to an Analog Devices Inc. component.
*
* THIS SOFTWARE IS PROVIDED BY ANALOG DEVICES "AS IS" AND ANY EXPRESS OR IMPLIED
* WARRANTIES, INCLUDING, BUT NOT LIMITED TO, NON-INFRINGEMENT, MERCHANTABILITY
* AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
* IN NO EVENT SHALL ANALOG DEVICES BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
* SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO,
* INTELLECTUAL PROPERTY RIGHTS, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
* LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
* ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
* (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
* SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*
*******************************************************************************
*   SVN Revision: $WCREV$
******************************************************************************/

#ifndef __DMA_H__
#define __DMA_H__

/*****************************************************************************/
/***************************** Types Definitions *****************************/
/*****************************************************************************/
typedef struct _stTransferDescriptor
{
    u32 NXTDESC_PNTR;
    u32 RESERVED1;
    u32 BUFFER_ADDR;
    u32 RESERVED2;
    u32 RESERVED3;
    u32 RESERVED4;
    u32 CONTROL;
    u32 STATUS;
    u32 APP0;
    u32 APP1;
    u32 APP2;
    u32 APP3;
    u32 APP4;
}stTransferDescriptor;

/*****************************************************************************/
/************************ Functions Declarations *****************************/
/*****************************************************************************/
void 	DMA_TransferDataTX(stTransferDescriptor* pCurrentDescriptor, 
						  stTransferDescriptor* pTailDescriptor);
u32 	DMA_IsTransferCompleteTX(void);

void 	DMA_TransferDataRX(stTransferDescriptor* pCurrentDescriptor, 
						   stTransferDescriptor* pTailDescriptor);
u32 	DMA_IsTransferCompleteRX(void);

#endif //__DMA_H__
